@@ -16,15 +16,17 @@
 # under the License.
 from __future__ import annotations
 
+import random
 import shlex
 import time
 from functools import cached_property
 from io import StringIO
 from typing import Any
 
-from google.api_core.retry import exponential_sleep_generator
+from googleapiclient.errors import HttpError
+from paramiko.ssh_exception import SSHException
 
-from airflow import AirflowException
+from airflow.exceptions import AirflowException
 from airflow.providers.google.cloud.hooks.compute import ComputeEngineHook
 from airflow.providers.google.cloud.hooks.os_login import OSLoginHook
 from airflow.providers.ssh.hooks.ssh import SSHHook
@@ -82,6 +84,8 @@ class ComputeEngineSSHHook(SSHHook):
         keys are managed using instance metadata
     :param expire_time: The maximum amount of time in seconds before the private key expires
     :param gcp_conn_id: The connection id to use when fetching connection information
+    :param max_retries: Maximum number of retries the process will try to establish connection to instance.
+        Could be decreased/increased by user based on the amount of parallel SSH connections to the instance.
     """
 
     conn_name_attr = "gcp_conn_id"
@@ -109,6 +113,7 @@ class ComputeEngineSSHHook(SSHHook):
         use_oslogin: bool = True,
         expire_time: int = 300,
         cmd_timeout: int | ArgNotSet = NOTSET,
+        max_retries: int = 10,
         **kwargs,
     ) -> None:
         if kwargs.get("delegate_to") is not None:
@@ -129,6 +134,7 @@ class ComputeEngineSSHHook(SSHHook):
         self.expire_time = expire_time
         self.gcp_conn_id = gcp_conn_id
         self.cmd_timeout = cmd_timeout
+        self.max_retries = max_retries
         self._conn: Any | None = None
 
     @cached_property
@@ -225,40 +231,59 @@ class ComputeEngineSSHHook(SSHHook):
             hostname = self.hostname
 
         privkey, pubkey = self._generate_ssh_key(self.user)
-        if self.use_oslogin:
-            user = self._authorize_os_login(pubkey)
-        else:
-            user = self.user
-            self._authorize_compute_engine_instance_metadata(pubkey)
 
-        proxy_command = None
-        if self.use_iap_tunnel:
-            proxy_command_args = [
-                "gcloud",
-                "compute",
-                "start-iap-tunnel",
-                str(self.instance_name),
-                "22",
-                "--listen-on-stdin",
-                f"--project={self.project_id}",
-                f"--zone={self.zone}",
-                "--verbosity=warning",
-            ]
-            proxy_command = " ".join(shlex.quote(arg) for arg in proxy_command_args)
-
-        sshclient = self._connect_to_instance(user, hostname, privkey, proxy_command)
+        max_delay = 10
+        sshclient = None
+        for retry in range(self.max_retries + 1):
+            try:
+                if self.use_oslogin:
+                    user = self._authorize_os_login(pubkey)
+                else:
+                    user = self.user
+                    self._authorize_compute_engine_instance_metadata(pubkey)
+                proxy_command = None
+                if self.use_iap_tunnel:
+                    proxy_command_args = [
+                        "gcloud",
+                        "compute",
+                        "start-iap-tunnel",
+                        str(self.instance_name),
+                        "22",
+                        "--listen-on-stdin",
+                        f"--project={self.project_id}",
+                        f"--zone={self.zone}",
+                        "--verbosity=warning",
+                    ]
+                    proxy_command = " ".join(shlex.quote(arg) for arg in proxy_command_args)
+                sshclient = self._connect_to_instance(user, hostname, privkey, proxy_command)
+                break
+            except (HttpError, AirflowException, SSHException) as exc:
+                if (isinstance(exc, HttpError) and exc.resp.status == 412) or (
+                    isinstance(exc, AirflowException) and "412 PRECONDITION FAILED" in str(exc)
+                ):
+                    self.log.info("Error occurred when trying to update instance metadata: %s", exc)
+                elif isinstance(exc, SSHException):
+                    self.log.info("Error occurred when establishing SSH connection using Paramiko: %s", exc)
+                else:
+                    raise
+                if retry == self.max_retries:
+                    raise AirflowException("Maximum retries exceeded. Aborting operation.")
+                delay = random.randint(0, max_delay)
+                self.log.info(f"Failed establish SSH connection, waiting {delay} seconds to retry...")
+                time.sleep(delay)
+        if not sshclient:
+            raise AirflowException("Unable to establish SSH connection.")
         return sshclient
 
     def _connect_to_instance(self, user, hostname, pkey, proxy_command) -> paramiko.SSHClient:
         self.log.info("Opening remote connection to host: username=%s, hostname=%s", user, hostname)
-        max_time_to_wait = 10
-        for time_to_wait in exponential_sleep_generator(initial=1, maximum=max_time_to_wait):
+        max_time_to_wait = 5
+        for time_to_wait in range(max_time_to_wait + 1):
             try:
                 client = _GCloudAuthorizedSSHClient(self._compute_hook)
                 # Default is RejectPolicy
                 # No known host checking since we are not storing privatekey
                 client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
-
                 client.connect(
                     hostname=hostname,
                     username=user,
@@ -268,8 +293,6 @@ class ComputeEngineSSHHook(SSHHook):
                 )
                 return client
             except paramiko.SSHException:
-                # exponential_sleep_generator is an infinite generator, so we need to
-                # check the end condition.
                 if time_to_wait == max_time_to_wait:
                     raise
             self.log.info("Failed to connect. Waiting %ds to retry", time_to_wait)
@@ -291,7 +314,7 @@ class ComputeEngineSSHHook(SSHHook):
                 item["value"] = keys
                 break
         else:
-            new_dict = dict(key="ssh-keys", value=keys)
+            new_dict = {"key": "ssh-keys", "value": keys}
             metadata["items"] = [new_dict]
 
         self._compute_hook.set_instance_metadata(
