@@ -18,10 +18,9 @@
 """This module contains a Google Cloud Text to Speech Hook."""
 from __future__ import annotations
 
-from typing import Sequence
+from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
-from google.api_core.retry import Retry
 from google.cloud.texttospeech_v1 import TextToSpeechClient
 from google.cloud.texttospeech_v1.types import (
     AudioConfig,
@@ -33,6 +32,9 @@ from google.cloud.texttospeech_v1.types import (
 from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 
+if TYPE_CHECKING:
+    from google.api_core.retry import Retry
+
 
 class CloudTextToSpeechHook(GoogleBaseHook):
     """
@@ -91,7 +93,7 @@ class CloudTextToSpeechHook(GoogleBaseHook):
         timeout: float | None = None,
     ) -> SynthesizeSpeechResponse:
         """
-        Synthesizes text input
+        Synthesizes text input.
 
         :param input_data: text input to be synthesized. See more:
             https://googleapis.github.io/google-cloud-python/latest/texttospeech/gapic/v1/types.html#google.cloud.texttospeech_v1.types.SynthesisInput
