@@ -28,20 +28,22 @@
 """
 from __future__ import annotations
 
-from typing import Sequence
+from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.client_options import ClientOptions
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
-from google.api_core.operation import Operation
-from google.api_core.retry import Retry
 from google.cloud.aiplatform_v1 import EndpointServiceClient
-from google.cloud.aiplatform_v1.services.endpoint_service.pagers import ListEndpointsPager
-from google.cloud.aiplatform_v1.types import DeployedModel, Endpoint
-from google.protobuf.field_mask_pb2 import FieldMask
 
-from airflow import AirflowException
+from airflow.exceptions import AirflowException
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 
+if TYPE_CHECKING:
+    from google.api_core.operation import Operation
+    from google.api_core.retry import Retry
+    from google.cloud.aiplatform_v1.services.endpoint_service.pagers import ListEndpointsPager
+    from google.cloud.aiplatform_v1.types import DeployedModel, Endpoint
+    from google.protobuf.field_mask_pb2 import FieldMask
+
 
 class EndpointServiceHook(GoogleBaseHook):
     """Hook for Google Cloud Vertex AI Endpoint Service APIs."""
@@ -316,8 +318,7 @@ class EndpointServiceHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> Operation:
         """
-        Undeploys a Model from an Endpoint, removing a DeployedModel from it, and freeing all resources it's
-        using.
+        Undeploys a Model from an Endpoint, removing a DeployedModel from it, and freeing all used resources.
 
         :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
         :param region: Required. The ID of the Google Cloud region that the service belongs to.
