@@ -21,18 +21,21 @@ import base64
 import json
 import os
 import re
-from typing import Callable, Iterable, TypeVar
+from typing import TYPE_CHECKING, Callable, Iterable, TypeVar
 from urllib.parse import urlsplit
 
 import dill
 
-from airflow import DAG
 from airflow.exceptions import AirflowException
 from airflow.operators.python import PythonOperator
+from airflow.providers.apache.beam.hooks.beam import BeamRunnerType
 from airflow.providers.apache.beam.operators.beam import BeamRunPythonPipelineOperator
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
 from airflow.providers.google.cloud.operators.mlengine import MLEngineStartBatchPredictionJobOperator
 
+if TYPE_CHECKING:
+    from airflow import DAG
+
 T = TypeVar("T", bound=Callable)
 
 
@@ -52,7 +55,7 @@ def create_evaluate_ops(
     version_name: str | None = None,
     dag: DAG | None = None,
     py_interpreter="python3",
-):
+) -> tuple[MLEngineStartBatchPredictionJobOperator, BeamRunPythonPipelineOperator, PythonOperator]:
     """
     Creates Operators needed for model evaluation and returns.
 
@@ -182,7 +185,6 @@ def create_evaluate_ops(
         issues check: https://issues.apache.org/jira/browse/BEAM-1251
 
     :returns: a tuple of three operators, (prediction, summary, validation)
-    :rtype: tuple(DataFlowPythonOperator, DataFlowPythonOperator,
                   PythonOperator)
     """
     batch_prediction_job_id = batch_prediction_job_id or ""
@@ -191,7 +193,7 @@ def create_evaluate_ops(
 
     # Verify that task_prefix doesn't have any special characters except hyphen
     # '-', which is the only allowed non-alphanumeric character by Dataflow.
-    if not re.match(r"^[a-zA-Z][-A-Za-z0-9]*$", task_prefix):
+    if not re.fullmatch(r"[a-zA-Z][-A-Za-z0-9]*", task_prefix):
         raise AirflowException(
             "Malformed task_id for DataFlowPythonOperator (only alphanumeric "
             "and hyphens are allowed but got: " + task_prefix
@@ -205,11 +207,11 @@ def create_evaluate_ops(
 
     if dag is not None and dag.default_args is not None:
         default_args = dag.default_args
-        project_id = project_id or default_args.get('project_id')
-        region = region or default_args['region']
-        model_name = model_name or default_args.get('model_name')
-        version_name = version_name or default_args.get('version_name')
-        dataflow_options = dataflow_options or default_args.get('dataflow_default_options')
+        project_id = project_id or default_args.get("project_id")
+        region = region or default_args["region"]
+        model_name = model_name or default_args.get("model_name")
+        version_name = version_name or default_args.get("version_name")
+        dataflow_options = dataflow_options or default_args.get("dataflow_default_options")
 
     evaluate_prediction = MLEngineStartBatchPredictionJobOperator(
         task_id=(task_prefix + "-prediction"),
@@ -228,15 +230,16 @@ def create_evaluate_ops(
     metric_fn_encoded = base64.b64encode(dill.dumps(metric_fn, recurse=True)).decode()
     evaluate_summary = BeamRunPythonPipelineOperator(
         task_id=(task_prefix + "-summary"),
-        py_file=os.path.join(os.path.dirname(__file__), 'mlengine_prediction_summary.py'),
+        runner=BeamRunnerType.DataflowRunner,
+        py_file=os.path.join(os.path.dirname(__file__), "mlengine_prediction_summary.py"),
         default_pipeline_options=dataflow_options,
         pipeline_options={
             "prediction_path": prediction_path,
             "metric_fn_encoded": metric_fn_encoded,
-            "metric_keys": ','.join(metric_keys),
+            "metric_keys": ",".join(metric_keys),
         },
         py_interpreter=py_interpreter,
-        py_requirements=['apache-beam[gcp]>=2.14.0'],
+        py_requirements=["apache-beam[gcp]>=2.46.0"],
         dag=dag,
     )
     evaluate_summary.set_upstream(evaluate_prediction)
